@@ -12,7 +12,7 @@ import pandas
 import requests
 import logging
 import sys
-from .._utils._constants import ACCOUNT, api_prefix
+from .._utils._constants import ACCOUNT
 from .._utils._utils import ApiInputs
 
 logger = logging.getLogger(__name__)
@@ -239,9 +239,9 @@ class Blob:
         blob_client.upload_blob(upload_object, blob_type="BlockBlob", overwrite=True)
 
 
-def _get_ingestion_connection_string(api_inputs: ApiInputs):
+def _get_ingestion_service_bus_connection_string(api_inputs: ApiInputs):
     """
-    Get connection string specific to Data Ingestion Storage
+    Get connection string specific to Data Ingestion Service Bus
 
     Parameters
     ----------
@@ -251,11 +251,11 @@ def _get_ingestion_connection_string(api_inputs: ApiInputs):
     Returns
     -------
     str
-        Data Ingestion connection string
+        Data Ingestion Service Bus connection string
     """
     headers = api_inputs.api_headers.default
 
-    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/storage"
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/service-bus"
     response = requests.request("GET", url, timeout=20, headers=headers)
 
     if response.status_code != 200:
@@ -290,7 +290,7 @@ def _get_container_sas_uri(api_inputs: ApiInputs, container: str, account: ACCOU
         container connection string
     """
 
-    if (container == None or len(container) == 0):
+    if container == None or len(container) == 0:
         logger.error('Must set a container to get Container connection string.')
 
     headers = api_inputs.api_headers.default
@@ -340,7 +340,8 @@ def _get_structure(df):
 
 def __get_storage_options(account: ACCOUNT):
     """
-    Get Storage Account Options. Currently the existing account literal doesn't match the Enum equivalent of storage options in the API, so we have this method
+    Get Storage Account Options. Currently the existing account literal doesn't match the Enum equivalent of storage
+    options in the API, so we have this method
 
     Parameters
     ----------
@@ -353,17 +354,17 @@ def __get_storage_options(account: ACCOUNT):
         API equivalent account storage name
     """
 
-    if (account == None or len(account) == 0):
+    if account == None or len(account) == 0:
         logger.error('Mapping to storage options requires Account Parameter Value.')
         return account
 
-    if (account == 'SwitchStorage'):
+    if account == 'SwitchStorage':
         return 'LegacySwitchStorage'
-    elif (account == 'SwitchContainer'):
+    elif account == 'SwitchContainer':
         return 'LegacySwitchContainer'
-    elif (account == 'Argus'):
+    elif account == 'Argus':
         return 'ArgusStorage'
-    elif (account == 'DataIngestion'):
+    elif account == 'DataIngestion':
         return 'DataIngestionStorage'
 
     return account
