@@ -4,7 +4,7 @@
 # license information.
 # --------------------------------------------------------------------------
 """
-A module for integrating asset creation, asset updates, data ingestion, etc into the Switch Automation platform.
+A module for integrating asset creation, asset updates, data ingestion, etc into the Switch Automation Platform.
 """
 import re
 import sys
@@ -410,7 +410,7 @@ def upsert_sites(df: pandas.DataFrame, api_inputs: ApiInputs, tag_columns: list
         - Longitude
         - Timezone
         - InstallationId
-            - The UUID of the existing site within the Switch Automation platform.
+            - The UUID of the existing site within the Switch Automation Platform.
 
     Parameters
     ----------
@@ -893,7 +893,7 @@ def upsert_data(data_frame, api_inputs: ApiInputs, table_name: str, key_columns:
 
     if len(key_columns) == 0 or key_columns is None:
         logger.error(
-            "You must provide key_columns. This allows the Switch Automation platform to identify the rows to update.")
+            "You must provide key_columns. This allows the Switch Automation Platform to identify the rows to update.")
         return False
 
     logger.info("Data is being upserted for %s", table_name)
@@ -1134,12 +1134,12 @@ def upsert_event_work_order_id(api_inputs: ApiInputs, event_task_id: uuid.UUID,
 
     payload = {
                   "IntegrationId": integration_id,
-                  "Status": status
+                  "Status": work_order_status
     }
 
     url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/events/{str(event_task_id)}/work-order"
 
-    response = requests.put(url=url, data=payload, headers=headers)
+    response = requests.put(url=url, data=payload, headers=header)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
         logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
